@@ -10,16 +10,42 @@ use Config::Tiny;
 
 use Date::Simple;
 
-use Hash::FieldHash ':all';
+use File::Slurper 'read_lines';
 
-use Perl6::Slurp; # For slurp().
+use Moo;
 
 use Text::Xslate 'mark_raw';
 
-fieldhash my %html_config   => 'html_config';
-fieldhash my %module_config => 'module_config';
+use Types::Standard qw/Any HashRef/;
 
-our $VERSION = '1.02';
+has html_config =>
+(
+	default  => sub{return {} },
+	is       => 'rw',
+	isa      => HashRef,
+	required => 0,
+);
+
+has module_config =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Any,
+	required => 0,
+);
+
+our $VERSION = '1.04';
+
+# --------------------------------------------------
+
+sub BUILD
+{
+	my($self) = @_;
+
+	$self -> html_config(Benchmark::Featureset::SetOps::Config -> new -> config);
+	$self -> module_config(Config::Tiny -> read('config/module.list.ini') );
+
+} # End of BUILD.
 
 # ------------------------------------------------
 
@@ -215,16 +241,15 @@ sub _build_templater
 
 # --------------------------------------------------
 
-sub _init
+sub log
 {
-	my($self, $arg)      = @_;
-	$$arg{html_config}   = Benchmark::Featureset::SetOps::Config -> new -> config;
-	$$arg{module_config} = Config::Tiny -> read('config/module.list.ini');
-	$self                = from_hash($self, $arg);
+	my($self, $level, $s) = @_;
+	$level ||= 'debug';
+	$s     ||= '';
 
-	return $self;
+	print "$level: $s\n";
 
-} # End of _init.
+} # End of log.
 
 # --------------------------------------------------
 
@@ -317,30 +342,6 @@ sub _process_overload_3
 
 } # End of _process_overload_3.
 
-# --------------------------------------------------
-
-sub log
-{
-	my($self, $level, $s) = @_;
-	$level ||= 'debug';
-	$s     ||= '';
-
-	print "$level: $s\n";
-
-} # End of log.
-
-# --------------------------------------------------
-
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-	$self            = $self -> _init(\%arg);
-
-	return $self;
-
-}	# End of new.
-
 # ------------------------------------------------
 
 sub run
@@ -377,7 +378,7 @@ sub _scan_source
 
 	chomp $path; # :-(.
 
-	my(@line) = slurp($path, {chomp => 1});
+	my(@line) = read_lines($path);
 
 	# 1: Process sub-classes.
 
@@ -389,7 +390,7 @@ sub _scan_source
 
 			chomp $path; # :-(.
 
-			push @line, slurp($path, {chomp => 1});
+			push @line, read_lines($path);
 		}
 	}
 
@@ -582,6 +583,10 @@ search.
 Also, I have 7 modules on CPAN which use L<Set::Array>, so I wanted a good idea of the array/set modules before
 I decided to switch.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Benchmark-Featureset-SetOps>
+
 =head1 See Also
 
 The modules compared in this package often have links to various modules, which I won't repeat here...
@@ -590,7 +595,7 @@ The other module in this series is L<Benchmark::Featureset::LocaleCountry>.
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -610,7 +615,7 @@ Home page: L<http://savage.net.au/index.html>.
 
 =head1 Copyright
 
-Australian copyright (c) 2011, Ron Savage.
+Australian copyright (c) 2012, Ron Savage.
 
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
